Index: tests/golem/golem_tests.dart |
diff --git a/tests/golem/golem_tests.dart b/tests/golem/golem_tests.dart |
index 9bbb5b5d3fb3477f3aa9a6f0eae67af3794c4687..c280de20199fb99847c5dfa86625a58b3d7e84bb 100644 |
--- a/tests/golem/golem_tests.dart |
+++ b/tests/golem/golem_tests.dart |
@@ -16,7 +16,7 @@ import 'dart:io' show |
import 'package:expect/expect.dart' show |
Expect; |
-import 'package:fletchc/src/guess_configuration.dart' show |
+import 'package:dartino_compiler/src/guess_configuration.dart' show |
executable; |
Future<Null> main() async { |
@@ -37,7 +37,7 @@ Future<Null> main() async { |
tarFile.toFilePath(), |
'-T', |
benchmarkingFiles.toFilePath(), |
- '$buildDir/fletch-vm', |
+ '$buildDir/dartino-vm', |
'$buildDir/dart', |
'$buildDir/natives.json']; |
@@ -77,7 +77,7 @@ Future<Null> main() async { |
ProcessResult snapshotResult = Process.runSync( |
'$buildDir/dart', |
['-Dsnapshot=out.snapshot', |
- 'tests/fletchc/run.dart', |
+ 'tests/dartino_compiler/run.dart', |
'benchmarks/DeltaBlue.dart'], |
workingDirectory: tempDir.path, |
runInShell: true); |
@@ -87,11 +87,11 @@ Future<Null> main() async { |
'stdout:\n${snapshotResult.stdout}\n' |
'stderr:\n${snapshotResult.stderr}'); |
// Run the snapshot in the temporary directory.Use the fletch-vm |
// binary in the archive to test that everything needed is in |
// there. |
ProcessResult runResult = Process.runSync( |
- '$buildDir/fletch-vm', |
+ '$buildDir/dartino-vm', |
['out.snapshot'], |
workingDirectory: tempDir.path, |
runInShell: true); |
@@ -87,11 +87,11 @@ Future<Null> main() async { |
'stdout:\n${snapshotResult.stdout}\n' |
'stderr:\n${snapshotResult.stderr}'); |
- // Run the snapshot in the temporary directory.Use the fletch-vm |
+ // Run the snapshot in the temporary directory.Use the dartino-vm |
// binary in the archive to test that everything needed is in |
// there. |